""""""

import simple_metrics_manager


def test_1():
    pass


if __name__ == "__main__":
    test_1()
